---
# piecash2

[![codecov](https://codecov.io/gh/sdementen/piecash2/branch/main/graph/badge.svg?token=piecash2_token_here)](https://codecov.io/gh/sdementen/piecash2)
[![CI](https://github.com/sdementen/piecash2/actions/workflows/main.yml/badge.svg)](https://github.com/sdementen/piecash2/actions/workflows/main.yml)

piecash using sqlalchemy 2

## Install it from PyPI

```bash
pip install piecash2
```

## Usage

```py
from piecash2 import BaseClass
from piecash2 import base_function

BaseClass().base_method()
base_function()
```

```bash
$ python -m piecash2
#or
$ piecash2
```

## Development

Read the [CONTRIBUTING.md](CONTRIBUTING.md) file.
